# BillingAccountSpec

Object describing the spec of a Billing Account

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**customer_id** | **str** | a guid describing the billing customer id | [optional] 
**product_id** | **str** | The Product this BillingAccount is associated with. | [optional] 
**dev_mode** | **bool** | Billing account is in dev mode, used for connecting to non-live backend billing API.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


